sqlobject.tests.test_sqlbuilder module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_sqlbuilder module

class `sqlobject.tests.test_sqlbuilder.` `SOTestSQLBuilder`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_sql_builder
  property `name`
  `q` = so_test_sql_builder
  property `so_value`
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_sqlbuilder.SOTestSQLBuilder`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_sql_builder'

`sqlobject.tests.test_sqlbuilder.` `test_ANY`()

`sqlobject.tests.test_sqlbuilder.` `test_CONCAT`()

`sqlobject.tests.test_sqlbuilder.` `test_Select`()

`sqlobject.tests.test_sqlbuilder.` `test_division`()

`sqlobject.tests.test_sqlbuilder.` `test_empty_AND`()

`sqlobject.tests.test_sqlbuilder.` `test_modulo`()

`sqlobject.tests.test_sqlbuilder.` `test_str_or_sqlrepr`()